@@ -100,8 +100,21 @@ class Madvr:
 
     def close_connection(self) -> None:
         """close the connection"""
-        self.client.close()
-        self.notification_client.close()
+        try:
+            self.client.close()
+        except AttributeError:
+            # means its already closed
+            pass
+        
+        try:
+            self.notification_client.close()
+        except AttributeError:
+            # means its already closed
+            pass
+
+        self.client = None
+        self.notification_client = None
+
         self.is_closed = True
 
         # Clear attr
@@ -337,6 +350,9 @@ class Madvr:
 
         # reconnect if client is not init or its off
         if self.client is None or self.is_on is False:
+            # Don't reconnect if poweroff or standby because HA will complain
+            if "PowerOff" in command or "Standby" in command:
+                return ""
             self.logger.debug("Connection lost - restarting connection")
             self._reconnect()
 
@@ -520,6 +536,8 @@ class Madvr:
 
         standby: bool -> standby instead of poweroff if true
         """
+        # dont do anything if its off besides mark it off
+        # sending command will open connection
         try:
             res = self.send_command("Standby" if standby else "PowerOff")
             self.close_connection()
